import time

from iwla import IWLA
from iplugin import IPlugin
from display import *

class IWLADisplayReferers(IPlugin):
    def __init__(self, iwla):
        super(IWLADisplayReferers, self).__init__(iwla)
        self.API_VERSION = 1
        self.requires = ['IWLAPostAnalysisReferers']

    def hook(self):
        display = self.iwla.getDisplay()
        month_stats = self.iwla.getMonthStats()
        referers = month_stats.get('referers', {})
        robots_referers = month_stats.get('robots_referers', {})
        search_engine_referers = month_stats.get('search_engine_referers', {})
        key_phrases = month_stats.get('key_phrases', {})

        top_referers = [(k, referers[k]['pages']) for k in referers.keys()]
        top_referers = sorted(top_referers, key=lambda t: t[1], reverse=True)

        top_robots_referers = [(k, robots_referers[k]['pages']) for k in robots_referers.keys()]
        top_robots_referers = sorted(top_robots_referers, key=lambda t: t[1], reverse=True)

        top_search_engine_referers = [(k, search_engine_referers[k]['pages']) for k in search_engine_referers.keys()]
        top_search_engine_referers = sorted(top_search_engine_referers, key=lambda t: t[1], reverse=True)

        top_key_phrases = key_phrases.items()
        top_key_phrases = sorted(top_key_phrases, key=lambda t: t[1], reverse=True)

        cur_time = self.iwla.getCurTime()
        index = self.iwla.getDisplayIndex()

        # All referers in a file
        title = time.strftime('Connexion from - %B %Y', cur_time)

        filename = 'referers.html'
        path = self.iwla.getCurDisplayPath(filename)

        page = display.createPage(title, path, self.iwla.getConfValue('css_path', []))
        table = display.createBlock(DisplayHTMLBlockTable, 'Connexion from', ['Origin', 'Pages', 'Hits'])
        table.setColsCSSClass(['', 'iwla_page', 'iwla_hit'])

        total_search = [0]*3
        table.appendRow(['<b>Search Engine</b>', '', ''])
        for r,_ in top_search_engine_referers:
            row = [r, search_engine_referers[r]['pages'], search_engine_referers[r]['hits']]
            total_search[1] += search_engine_referers[r]['pages']
            total_search[2] += search_engine_referers[r]['hits']
            table.appendRow(row)

        total_external = [0]*3
        table.appendRow(['<b>External URL</b>', '', ''])
        for r,_ in top_referers:
            row = [generateHTMLLink(r), referers[r]['pages'], referers[r]['hits']]
            total_external[1] += referers[r]['pages']
            total_external[2] += referers[r]['hits']
            table.appendRow(row)

        total_robot = [0]*3
        table.appendRow(['<b>External URL (robot)</b>', '', ''])
        for r,_ in top_robots_referers:
            row = [generateHTMLLink(r), robots_referers[r]['pages'], robots_referers[r]['hits']]
            total_robot[1] += robots_referers[r]['pages']
            total_robot[2] += robots_referers[r]['hits']
            table.appendRow(row)

        page.appendBlock(table)

        display.addPage(page)

        link = '<a href=\'%s\'>All referers</a>' % (filename)

        # Top referers in index
        title = '%s - %s' % ('Connexion from', link)

        table = display.createBlock(DisplayHTMLBlockTable, title, ['Origin', 'Pages', 'Hits'])
        table.setColsCSSClass(['', 'iwla_page', 'iwla_hit'])

        table.appendRow(['<b>Search Engine</b>', '', ''])
        for r,_ in top_search_engine_referers[:10]:
            row = [r, search_engine_referers[r]['pages'], search_engine_referers[r]['hits']]
            total_search[1] -= search_engine_referers[r]['pages']
            total_search[2] -= search_engine_referers[r]['hits']
            table.appendRow(row)
        if total_search[1] or total_search[2]:
            total_search[0] = 'Others'
            table.appendRow(total_search)
            table.setCellCSSClass(table.getNbRows()-1, 0, 'iwla_others')

        table.appendRow(['<b>External URL</b>', '', ''])
        for r,_ in top_referers[:10]:
            row = [generateHTMLLink(r), referers[r]['pages'], referers[r]['hits']]
            total_external[1] -= referers[r]['pages']
            total_external[2] -= referers[r]['hits']            
            table.appendRow(row)
        if total_external[1] or total_external[2]:
            total_external[0] = 'Others'
            table.appendRow(total_external)
            table.setCellCSSClass(table.getNbRows()-1, 0, 'iwla_others')

        table.appendRow(['<b>External URL (robot)</b>', '', ''])
        for r,_ in top_robots_referers[:10]:
            row = [generateHTMLLink(r), robots_referers[r]['pages'], robots_referers[r]['hits']]
            total_robot[1] -= robots_referers[r]['pages']
            total_robot[2] -= robots_referers[r]['hits']
            table.appendRow(row)
        if total_robot[1] or total_robot[2]:
            total_robot[0] = 'Others'
            table.appendRow(total_robot)
            table.setCellCSSClass(table.getNbRows()-1, 0, 'iwla_others')

        index.appendBlock(table)

        # All key phrases in a file
        title = time.strftime('Key Phrases - %B %Y', cur_time)

        filename = 'key_phrases.html'
        path = self.iwla.getCurDisplayPath(filename)

        total_search = [0]*2
        page = display.createPage(title, path, self.iwla.getConfValue('css_path', []))
        table = display.createBlock(DisplayHTMLBlockTable, 'Top key phrases', ['Key phrase', 'Search'])
        table.setColsCSSClass(['', 'iwla_search'])
        for phrase in top_key_phrases:
            table.appendRow([phrase[0], phrase[1]])
            total_search[1] += phrase[1]
        page.appendBlock(table)

        display.addPage(page)

        link = '<a href=\'%s\'>All key phrases</a>' % (filename)

        # Top key phrases in index
        title = '%s - %s' % ('Top key phrases', link)
        table = display.createBlock(DisplayHTMLBlockTable, title, ['Key phrase', 'Search'])
        table.setColsCSSClass(['', 'iwla_search'])
        for phrase in top_key_phrases[:10]:
            table.appendRow([phrase[0], phrase[1]])
            total_search[1] -= phrase[1]
        if total_search[1]:
            total_search[0] = 'Others'
            table.appendRow(total_search)
            table.setCellCSSClass(table.getNbRows()-1, 0, 'iwla_others')
        index.appendBlock(table)
