import time

from iwla import IWLA
from iplugin import IPlugin
from display import *

class IWLADisplayTopHits(IPlugin):
    def __init__(self, iwla):
        super(IWLADisplayTopHits, self).__init__(iwla)
        self.API_VERSION = 1
        self.requires = ['IWLAPostAnalysisTopHits']

    def hook(self):
        display = self.iwla.getDisplay()
        top_hits = self.iwla.getMonthStats()['top_hits']
        top_hits = sorted(top_hits.items(), key=lambda t: t[1], reverse=True)

        # All in a file
        title = time.strftime('All Hits - %B %Y', self.iwla.getCurTime())
        filename = 'top_hits.html'
        path = self.iwla.getCurDisplayPath(filename)

        page = display.createPage(title, path, self.iwla.getConfValue('css_path', []))
        table = display.createBlock(DisplayHTMLBlockTable, 'All Hits', ['URI', 'Entrance'])        
        table.setColsCSSClass(['', 'iwla_hit'])
        total_hits = [0]*2
        for (uri, entrance) in top_hits:
            table.appendRow([generateHTMLLink(uri), entrance])
            total_hits[1] += entrance
        page.appendBlock(table)
                        
        display.addPage(page)

        link = '<a href=\'%s\'>All hits</a>' % (filename)
        title = '%s - %s' % ('Top Hits', link)

        # Top in index
        index = self.iwla.getDisplayIndex()
        
        table = display.createBlock(DisplayHTMLBlockTable, title, ['URI', 'Entrance'])        
        table.setColsCSSClass(['', 'iwla_hit'])
        for (uri, entrance) in top_hits[:10]:
            table.appendRow([generateHTMLLink(uri), entrance])
            total_hits[1] -= entrance
        if total_hits[1]:
            total_hits[0] = 'Others'
            table.appendRow(total_hits)
            table.setCellCSSClass(table.getNbRows()-1, 0, 'iwla_others')
        index.appendBlock(table)
